<?php
Namespace App\Controller\Admin\Inventory;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Validator\Validation;
use Symfony\Component\Validator\Constraints as Assert;
use App\Model\Admin\HomegearVariable;
use App\Model\Admin\HomegearRoom;
use App\Model\Admin\HomegearGroup;
use App\Model\Admin\HomegearHistory;

class VariableController extends Controller
{
    public function indexAction(Request $request, HomegearVariable $var)
    {
        return $this->render('Admin/Inventory/Variable/list.html.twig', array(
            'sect' => $request->attributes->get('sect'),
            'variables' => $var->loadAll()
        ));
    }

    public function createAction(Request $request, HomegearVariable $var)
    {
        // Validate the input
        $validator = Validation::createValidator();
        $constraint = new Assert\Collection(array(
            'name' => new Assert\NotBlank,
            'type' => new Assert\NotBlank,
            'flag' => new Assert\NotBlank
        ));
        $params = $request->request->all();
        $errorList = $validator->validate($params, $constraint);
        if (0 === count($errorList)) {
            $result = $var->create($params['name'],$params['type'],$params['flag']);
        }
        // TODO: check result and redirect with flash
        return $this->redirectToRoute('admin.inventory.variables');
    }

    public function editAction($id, Request $request, HomegearVariable $var, HomegearRoom $room, HomegearGroup $group, HomegearHistory $history)
    {
        $id = base64_decode($id);
        return $this->render('Admin/Inventory/Variable/edit.html.twig', array(
            'sect' => $request->attributes->get('sect'),
            'variable' => $var->loadByName($id),
            'rooms' => $room->loadAllForDevice($id),
            'groups' => $group->loadAllForDevice($id),
            'hasInflux' => $history->checkInfluxDb(),
            'history' => $history->getMeasurementsByDevice(0,$id)
        ));
    }

    public function updateAction($id, Request $request, HomegearVariable $var, HomegearRoom $room, HomegearGroup $group) {
        $id = base64_decode($id);
        $params = $request->request->all();
        $var->create($params['name'],$params['type'],$params['flag'],$params['value']);
        if (!array_key_exists('rooms', $params)) {
            // set an empty rooms-array even if there is none ... we need this to delete the device from all rooms
            $params['rooms'] = array();
        }
        if (!array_key_exists('groups', $params)) {
            // set an empty groups-array even if there is none ... we need this to delete the device from all groups
            $params['groups'] = array();
        }
        $room->updateSysvarInRooms($id,$params['rooms']);
        $group->updateSysvarInGroups($id,$params['groups']);
        if (array_key_exists('goback',$params) && $params['goback'] != '0') {
            return $this->redirectToRoute($params['goback']);
        }
        return $this->redirectToRoute('admin.inventory.variables.edit', array('id' => base64_encode($id)),301);
    }

    public function deleteAction($id, Request $request, HomegearVariable $var, HomegearHistory $history)
    {
        if ($id == '-1') {
            // mass-delete
            $params = $request->request->all();
            if (is_array($params) && array_key_exists('deleteVariables',$params)) {
                foreach ($params['deleteVariables'] as $deviceId) {
                    $myid = base64_decode($deviceId);
                    $history->deleteAllByItem(0,$myid);
                    $var->delete($myid);
                }
            }
            return new JsonResponse();
        } else {
            $id = base64_decode($id);
            $history->deleteAllByItem(0,$id);
            $var->delete($id);
            return $this->redirectToRoute('admin.inventory.variables');
        }
    }

    public function addHistoryAction($id, HomegearVariable $var, HomegearHistory $history)
    {
        $id = base64_decode($id);
        // use 0 as peerId and -1 as channel for variables ... see: https://ref.homegear.eu/rpc.html#influxdbSetLogging
        $history->addMeasurement(0,-1,$id);
        return $this->redirectToRoute('admin.inventory.variables.edit', array('id' => base64_encode($id)));
    }

    public function deleteHistoryAction($id, HomegearHistory $history)
    {
        $id = base64_decode($id);
        // use 0 as peerId and -1 as channel for variables ... see: https://ref.homegear.eu/rpc.html#influxdbSetLogging
        $result = $history->deleteMeasurement(0,-1,$id);
        return $this->redirectToRoute('admin.inventory.variables.edit',array('id' => base64_encode($id)));
    }

    public function getVarsFromCcuAction(Request $request, HomegearVariable $var)
    {
        $params = $request->request->all();
        //$params = $request->query->all();
        //dump($params);
        $result = $var->getFromCcu($params);
        return new JsonResponse($result);
    }
}