<?php
Namespace App\Controller\Admin;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Translation\TranslatorInterface;
use Symfony\Component\HttpFoundation\Session\Session;
use App\Model\Admin\HomegearServiceMessage;
use App\Utils\Utils;

class LayoutController extends Controller
{
    private $user;

    public function header(Request $request, TranslatorInterface $translator, HomegearServiceMessage $messages)
    {
        $this->user = $this->getUser();
        $systemMsg = $messages->list($request->getSession()->get('_locale'));
        if (is_array($systemMsg)) {
            $session = new Session();
            foreach ($systemMsg as $msg) {
                if ((array_key_exists('TYPE',$msg) && $msg['TYPE'] == 1) && (array_key_exists('DATA',$msg))) {
                    if (is_array($msg['DATA']) && !array_key_exists('SERIALNUMBER',$msg['DATA'])) {
                        $session->getFlashBag()->set('warning-system',$translator->trans('flash.service_message',array('%url%' => $this->get('router')->generate('admin.servicemessages')),'admin'));
                    } else if (!is_array($msg['DATA'])) {
                        $session->getFlashBag()->set('warning-system',$translator->trans('flash.service_message',array('%url%' => $this->get('router')->generate('admin.servicemessages')),'admin'));
                    }
                }
            }
        }
        return $this->render('Admin/header.html.twig', array(
            'locale' => $request->getSession()->get('_locale'),
            'currentUser' => $this->user->getUsername(),
            'serviceMessages' => $systemMsg
        ));
    }
    
    public function navigation($sect,$route, Utils $utils)
    {
        $userSettings = \Homegear\Homegear::getUserMetadata($this->user->getUsername());

        $release = $utils->checkRelease();
        $navigation = array();
        $routes = $this->get('router')->getRouteCollection();
        $isOSS = (substr($_SERVER['REQUEST_URI'],0,6) !== '/admin' ? false : true );
        foreach ($routes as $key => $myRoute) {
            if (strpos($key, 'admin.') === 0) {
                $defaults = $myRoute->getDefaults();

                if (array_key_exists('name',$defaults) && $defaults['name'] == 'navigation.item.roles' && $release !== 'dev') { continue; }
                if(array_key_exists('expert', $defaults) && $defaults['expert'] === true && (!array_key_exists('expert', $userSettings) || $userSettings['expert'] !== "true")) continue;

                if(array_key_exists('name', $defaults) && $defaults['name'] == 'navigation.item.webssh') {
                    if(!call_user_func("Homegear\\Homegear::system.listMethods", "websshInput")) continue;
                    if(!$_SERVER['WEBSOCKET_ENABLED'] || $_SERVER['WEBSOCKET_AUTH_TYPE'] != 'session') continue;
                }

                // disable some parts of the navigation if not supported by installed version
                if (array_key_exists('name', $defaults)) {
                    if ($defaults['name'] == 'navigation.item.buildings') {
                        if(!call_user_func("Homegear\\Homegear::system.listMethods", "getBuildings")) continue;
                    }
                    if ($defaults['name'] == 'navigation.item.profiles') {
                        if(!call_user_func("Homegear\\Homegear::system.listMethods", "getVariableProfile")) continue;
                    }
                    if ($defaults['name'] == 'navigation.item.mqtt') {
                        if ($isOSS) { continue; }
                        try {
                            if (!\Homegear\Homegear::managementDpkgPackageInstalled("mosquitto")) { continue; }
                        } catch(\Homegear\HomegearException $e) {
                            continue;
                        }
                    }
                    if ($defaults['name'] == 'navigation.item.wizard' && $isOSS) { continue; }
                    if ($defaults['name'] == 'navigation.item.info' && $isOSS) { continue; }
                    if ($defaults['name'] == 'navigation.item.mqtt' && $isOSS) { continue; }
                    if ($defaults['name'] == 'navigation.item.node-blue') {
                        if (! $utils->getNodeBlueEnabled()) {
                            continue;
                        }
                    }
                }
                if (array_key_exists('main_navigation', $defaults) && $defaults['main_navigation'] == 1) {
                    if ($defaults['sect'] == 'control' && array_key_exists('afterLogin',$userSettings)) {
                        $navigation[$defaults['sect']] = ['name' => $defaults['name'], 'path' => $userSettings['afterLogin'], 'icon' => $defaults['icon'], 'sort' => $defaults['sort'], 'sect' => $defaults['sect'], 'target' => (array_key_exists('target', $defaults) ? $defaults['target'] : ''), 'css' => (array_key_exists('css', $defaults) ? $defaults['css'] : '')];
                    } else {
                        $navigation[$defaults['sect']] = ['name' => $defaults['name'], 'path' => $key, 'icon' => $defaults['icon'], 'sort' => $defaults['sort'], 'sect' => $defaults['sect'], 'target' => (array_key_exists('target', $defaults) ? $defaults['target'] : ''), 'css' => (array_key_exists('css', $defaults) ? $defaults['css'] : '')];
                    }
                }
                if (array_key_exists('sub_navigation', $defaults) && $defaults['sub_navigation'] == 1) {
                    $navigation[$defaults['sect']]['sub_navigation'][$defaults['sort']] = ['name' => $defaults['name'], 'path' => $key, 'icon' => $defaults['icon'], 'sect' => $defaults['sect'], 'target' => (array_key_exists('target',$defaults) ? $defaults['target'] : '')];
                }
            }
        }
        foreach ($navigation as $key => $value) {
            $navigation[$value['sort']] = $navigation[$key];
            unset($navigation[$key]);
            if (array_key_exists('sub_navigation',$navigation[$value['sort']])) {
                ksort($navigation[$value['sort']]['sub_navigation']);
            }
        }
        ksort($navigation);
        return $this->render('Admin/navigation.html.twig', array(
            'sect' => $sect,
            'route' => $route,
            'navigation' => $navigation
        ));
    }
}