<?php
Namespace App\Controller\Admin\Settings;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Validator\Validation;
use Symfony\Component\Validator\Constraints as Assert;
use App\Model\Admin\CloudMatic;
use App\Utils\Utils;

class CloudMaticController extends Controller
{

    public function indexAction(Request $request, CloudMatic $cm, Utils $utils)
    {
        if ($cm->checkOpenVPN() === false) {
            return $this->render('Admin/Settings/CloudMatic/noOpenVPN.html.twig',array(
                'sect' => $request->attributes->get('sect')
            ));
        }
        $cmData = $cm->load();
        if ($cmData === null) {
            return $this->render('Admin/Settings/CloudMatic/register.html.twig',array(
                'sect' => $request->attributes->get('sect')
            ));
        } else {
            $expert = false;
            $userSettings = \Homegear\Homegear::getUserMetadata($this->getUser()->getUsername());
            if (array_key_exists('expert',$userSettings) && $userSettings['expert'] == 'true') {
                $expert = true;
            }
            return $this->render('Admin/Settings/CloudMatic/index.html.twig',array(
                'sect' => $request->attributes->get('sect'),
                'mgmt' => $utils->checkManagementRunning(),
                'vpn' => $cmData,
                'ocusers' => $cm->getOcservUsers(),
                'occonfig' => $cm->getOcservConfig(),
                'expert' => $expert
            ));
        }
    }

    public function restartOpenVPNAction(CloudMatic $cm)
    {
        return new JsonResponse(array('result' => $cm->restartOpenVPN()));
    }

    public function manualUpdateAction(CloudMatic $cm)
    {
        return new JsonResponse(array('result' => $cm->manualUpdate()));
    }

    public function uploadkeyAction(Request $request, CloudMatic $cm)
    {
        $file = $request->files->get('keyfile');
        if ($file !== null) {
            $cm->uploadKeyfile($file);
        }
        // TODO: return json for result
        //return new JsonResponse(array('result' => $cm->uploadKeyfile($file)));
        return $this->redirectToRoute('admin.settings.cloudmatic');
    }

    public function checkConnectionAction(CloudMatic $cm)
    {
        return new JsonResponse(array('result' => $cm->checkConnectionForRegistration()));
    }

    public function checkMailAction(Request $request, CloudMatic $cm)
    {
        return new JsonResponse($cm->checkMail($request->request->get('mail')));
    }

    public function doRegisterAction(Request $request, CloudMatic $cm)
    {
        // Validate the input
        $validator = Validation::createValidator();
        $constraint = new Assert\Collection(array(
            'fields' => array(
                'MAIL' => new Assert\NotBlank,
                'FNAME' => new Assert\NotBlank,
                'LNAME' => new Assert\NotBlank,
                'STRASSE' => new Assert\NotBlank,
                'PLZ' => new Assert\NotBlank,
                'ORT' => new Assert\NotBlank,
                'LAND' => new Assert\NotBlank,
            ),
            'allowExtraFields' => true
        ));
        $params = $request->request->all();
        $errorList = $validator->validate($params, $constraint);
        if (0 === count($errorList)) {
            $result = $cm->doRegister($params['MAIL'],$params['FNAME'],$params['LNAME'],$params['FIRMA'],$params['STRASSE'],$params['PLZ'],$params['ORT'],$params['LAND'],$params['USTID']);
            return new JsonResponse(array('result' => $result));
        }
        return new JsonResponse(array('result' => '0'));
    }

    public function removeAccountAction(Request $request, CloudMatic $cm)
    {
        $cm->removeAccount();
        return $this->redirectToRoute('admin.settings.cloudmatic',array(),301);
    }

    public function enableSupportAction(Request $request, CloudMatic $cm)
    {
        $cm->enableSupport();
        return $this->redirectToRoute('admin.settings.cloudmatic',array(),301);
    }

    public function disableSupportAction(Request $request, CloudMatic $cm)
    {
        $cm->disableSupport();
        return $this->redirectToRoute('admin.settings.cloudmatic',array(),301);
    }

    public function updateOcservConfigAction(Request $request, CloudMatic $cm)
    {
        // Validate the input
        $validator = Validation::createValidator();
        $constraint = new Assert\Collection(array(
            'enabled' => new Assert\NotBlank,
            'network' => new Assert\NotBlank
        ));
        $params = $request->request->all();
        $errorList = $validator->validate($params, $constraint);
        if (0 === count($errorList)) {
            $result = $cm->setOcservConfig($params);
        }
        return new JsonResponse($result);
    }

    public function addOcservUserAction(Request $request, CloudMatic $cm)
    {
        // Validate the input
        $validator = Validation::createValidator();
        $constraint = new Assert\Collection(array(
            'username' => new Assert\NotBlank,
            'password' => new Assert\NotBlank
        ));
        $params = $request->request->all();
        $errorList = $validator->validate($params, $constraint);
        if (0 === count($errorList)) {
            $result = $cm->addOcservUser($params);
        }
        return $this->redirectToRoute('admin.settings.cloudmatic',array(),301);
    }

    public function updateOcservUserAction(Request $request, CloudMatic $cm)
    {
        // Validate the input
        $validator = Validation::createValidator();
        $constraint = new Assert\Collection(array(
            'username' => new Assert\NotBlank,
            'password' => new Assert\NotBlank
        ));
        $params = $request->request->all();
        $errorList = $validator->validate($params, $constraint);
        if (0 === count($errorList)) {
            $result = $cm->addOcservUser($params);
        }
        return $this->redirectToRoute('admin.settings.cloudmatic',array(),301);
    }

    public function deleteOcservUserAction(Request $request, CloudMatic $cm)
    {
        // Validate the input
        $validator = Validation::createValidator();
        $constraint = new Assert\Collection(array(
            'username' => new Assert\NotBlank
        ));
        $params = $request->request->all();
        $errorList = $validator->validate($params, $constraint);
        if (0 === count($errorList)) {
            $result = $cm->deleteOcservUser($params);
        }
        return $this->redirectToRoute('admin.settings.cloudmatic',array(),301);
    }

}