<?php

namespace App\Security;

use App\Security\User\HomegearUser;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\RouterInterface;
use Symfony\Component\Security\Core\User\UserInterface;
use Symfony\Component\Security\Guard\AbstractGuardAuthenticator;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\Security\Core\User\UserProviderInterface;
use Symfony\Component\Security\Http\Util\TargetPathTrait;

class HomegearAuthenticator extends AbstractGuardAuthenticator
{
    use TargetPathTrait;
    private $router;

    public function __construct(RouterInterface $router)
    {
        $this->router = $router;
    }
    /**
     * Called on every request to decide if this authenticator should be
     * used for the request. Returning false will cause this authenticator
     * to be skipped.
     */
    public function supports(Request $request)
    {
        return $request->getPathInfo() == '/login';
    }

    /**
     * Called on every request. Return whatever credentials you want to
     * be passed to getUser() as $credentials.
     */
    public function getCredentials(Request $request)
    {
        return array(
            'username' => strtolower($request->get('_username')),
            'password' => $request->get('_password')
        );
    }

    public function getUser($credentials, UserProviderInterface $userProvider)
    {
        $username = ($credentials['username'] != '' ? $credentials['username'] : null);
        $password = ($credentials['password'] != '' ? $credentials['password'] : null);

        if (null === $username || null === $password) {
            return;
        }

        $hg = new \Homegear\Homegear;
        if ($hg->auth($username,$password) === false) {
            return;
        }
            
        $_SESSION['user'] = $username;
        return $userProvider->loadUserByUsername($username);
    }

    public function checkCredentials($credentials, UserInterface $user)
    {
        // check credentials - e.g. make sure the password is valid
        // no credential check is needed in this case
        return true;
    }

    public function onAuthenticationSuccess(Request $request, TokenInterface $token, $providerKey)
    {
        // if the user hits a secure page and start() was called, this was
        // the URL they were on, and probably where you want to redirect to
        $targetPath = $this->getTargetPath($request->getSession(), $providerKey);
        if (!$targetPath) {
            if (substr($_SERVER['REQUEST_URI'],0,6) !== '/admin') {
                $targetPath = $this->router->generate('index');
            } else {
                $targetPath = $this->router->generate('admin.dashboard');
            }
        }
        if (substr($_SERVER['REQUEST_URI'],0,6) !== '/admin') {
            // only redirect to 'afterLogin' if no targetPath (eg admin) was found
            #if ($token->getUser()->afterLogin && preg_match('/\/ui\/$/',$targetPath)) {
            if (preg_match('/\/ui\/$/',$targetPath)) {
                $afterLogin = $token->getUser()->afterLogin;
                if ($afterLogin && $afterLogin == 'room') {
                    $targetPath = $this->router->generate($afterLogin, ['id' => $token->getUser()->room]);
                } elseif ($afterLogin && $afterLogin == 'story') {
                    $targetPath = $this->router->generate($afterLogin, ['id' => $token->getUser()->story]);
                } elseif ($afterLogin) {
                    $targetPath = $this->router->generate($token->getUser()->afterLogin);
                }
            }
        }
        return new RedirectResponse($targetPath);
    }

    public function onAuthenticationFailure(Request $request, AuthenticationException $exception)
    {
        #dump($request);exit;
    }

    /**
     * Called when authentication is needed, but it's not sent
     */
    public function start(Request $request, AuthenticationException $authException = null)
    {
        $url = $this->router->generate('login');
        return new RedirectResponse($url);
    }

    public function supportsRememberMe()
    {
        return false;
    }
}